# pytruelayer
No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v1.0
- Package version: 0.1.0
- Build package: eu.rienafairefr.customcodegen.PythonCustomCodegen
For more information, please visit [https://truelayer.com](https://truelayer.com)

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/rienafairefr/pytruelayer.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/rienafairefr/pytruelayer.git`)

Then import the package:
```python
import truelayer
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import truelayer
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import truelayer
from truelayer.rest import ApiException
from pprint import pprint

configuration = truelayer.Configuration()
# Configure OAuth2 access token for authorization: oauth2
configuration.access_token = 'YOUR_ACCESS_TOKEN'

# Defining host is optional and default to https://api.truelayer.com/data/v1
configuration.host = "https://api.truelayer.com/data/v1"
# Enter a context with an instance of the API client
with truelayer.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = truelayer.DataApi(api_client)
    account_id = 'account_id_example' # str | 

    try:
        api_response = api_instance.data_v1_accounts_by_account_id_balance_get(account_id)
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling DataApi->data_v1_accounts_by_account_id_balance_get: %s\n" % e)
    
```

## Documentation for API Endpoints

All URIs are relative to *https://api.truelayer.com/data/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DataApi* | [**data_v1_accounts_by_account_id_balance_get**](docs/DataApi.md#data_v1_accounts_by_account_id_balance_get) | **GET** /accounts/{account_id}/balance | 
*DataApi* | [**data_v1_accounts_by_account_id_get**](docs/DataApi.md#data_v1_accounts_by_account_id_get) | **GET** /accounts/{account_id} | 
*DataApi* | [**data_v1_accounts_by_account_id_transactions_get**](docs/DataApi.md#data_v1_accounts_by_account_id_transactions_get) | **GET** /accounts/{account_id}/transactions | 
*DataApi* | [**data_v1_accounts_get**](docs/DataApi.md#data_v1_accounts_get) | **GET** /accounts | 
*DataApi* | [**data_v1_cards_by_account_id_balance_get**](docs/DataApi.md#data_v1_cards_by_account_id_balance_get) | **GET** /cards/{account_id}/balance | 
*DataApi* | [**data_v1_cards_by_account_id_get**](docs/DataApi.md#data_v1_cards_by_account_id_get) | **GET** /cards/{account_id} | 
*DataApi* | [**data_v1_cards_by_account_id_transactions_get**](docs/DataApi.md#data_v1_cards_by_account_id_transactions_get) | **GET** /cards/{account_id}/transactions | 
*DataApi* | [**data_v1_cards_get**](docs/DataApi.md#data_v1_cards_get) | **GET** /cards | 
*DataApi* | [**data_v1_info_get**](docs/DataApi.md#data_v1_info_get) | **GET** /info | 
*DataApi* | [**data_v1_me_get**](docs/DataApi.md#data_v1_me_get) | **GET** /me | 
*DataApi* | [**data_v1_results_by_task_id_get**](docs/DataApi.md#data_v1_results_by_task_id_get) | **GET** /results/{task_id} | 


## Documentation For Models

 - [APIResponseAccount](docs/APIResponseAccount.md)
 - [APIResponseBalance](docs/APIResponseBalance.md)
 - [APIResponseCard](docs/APIResponseCard.md)
 - [APIResponseCardBalance](docs/APIResponseCardBalance.md)
 - [APIResponseCardTransaction](docs/APIResponseCardTransaction.md)
 - [APIResponseInfo](docs/APIResponseInfo.md)
 - [APIResponseMe](docs/APIResponseMe.md)
 - [APIResponseTransaction](docs/APIResponseTransaction.md)
 - [Account](docs/Account.md)
 - [AccountNumber](docs/AccountNumber.md)
 - [AddressInfo](docs/AddressInfo.md)
 - [Balance](docs/Balance.md)
 - [CachedAPIResponseObject](docs/CachedAPIResponseObject.md)
 - [Card](docs/Card.md)
 - [CardBalance](docs/CardBalance.md)
 - [CardTransaction](docs/CardTransaction.md)
 - [Info](docs/Info.md)
 - [Me](docs/Me.md)
 - [ProviderInfo](docs/ProviderInfo.md)
 - [Transaction](docs/Transaction.md)


## Documentation For Authorization


## oauth2

- **Type**: OAuth
- **Flow**: implicit
- **Authorization URL**: https://auth.truelayer.com
- **Scopes**: 
 - **accounts**: Read access to accounts numbers
 - **balance**: Read access to balance
 - **info**: Read access to personal information
 - **transactions**: Read access to account transactions


## Author

rienafairefr@gmail.com


